@@ -1042,10 +1042,7 @@ seafile_from_json (const char *id, void *data, int len)
     object = json_loadb ((const char *)decompressed, outlen, 0, &error);
     g_free (decompressed);
     if (!object) {
-        if (error.text)
-            seaf_warning ("Failed to load seafile json object: %s.\n", error.text);
-        else
-            seaf_warning ("Failed to load seafile json object.\n");
+        seaf_warning ("Failed to load seafile json object: %s.\n", error.text);
         return NULL;
     }
 
@@ -1515,10 +1512,7 @@ seaf_dir_from_json (const char *dir_id, uint8_t *data, int len)
     object = json_loadb ((const char *)decompressed, outlen, 0, &error);
     g_free (decompressed);
     if (!object) {
-        if (error.text)
-            seaf_warning ("Failed to load seafdir json object: %s.\n", error.text);
-        else
-            seaf_warning ("Failed to load seafdir json object.\n");
+        seaf_warning ("Failed to load seafdir json object: %s.\n", error.text);
         return NULL;
     }
 
@@ -1807,10 +1801,7 @@ parse_metadata_type_json (const char *obj_id, uint8_t *data, int len)
     object = json_loadb ((const char *)decompressed, outlen, 0, &error);
     g_free (decompressed);
     if (!object) {
-        if (error.text)
-            seaf_warning ("Failed to load fs json object: %s.\n", error.text);
-        else
-            seaf_warning ("Failed to load fs json object.\n");
+        seaf_warning ("Failed to load fs json object: %s.\n", error.text);
         return SEAF_METADATA_TYPE_INVALID;
     }
 
@@ -1863,10 +1854,7 @@ fs_object_from_json (const char *obj_id, uint8_t *data, int len)
     object = json_loadb ((const char *)decompressed, outlen, 0, &error);
     g_free (decompressed);
     if (!object) {
-        if (error.text)
-            seaf_warning ("Failed to load fs json object: %s.\n", error.text);
-        else
-            seaf_warning ("Failed to load fs json object.\n");
+        seaf_warning ("Failed to load fs json object: %s.\n", error.text);
         return NULL;
     }
 
